solve_QP1QC: Solve (non-convex) quadratic program with 1 quadratic...

Description Usage Arguments Details Value

View source: R/qp1qc_solver.R

Description

Solves a possibly non-convex quadratic program with 1 quadratic constraint. Either A_mat or B_mat must be positive definite, but not necessarily both (see Details, below).

Usage

1
2
solve_QP1QC(A_mat, a_vec, B_mat, b_vec, k, tol = 10^-7,
  eigen_B_mat = NULL, eigen_A_mat = NULL, verbose = TRUE)

Arguments

A_mat

see details below

a_vec

see details below

B_mat

see details below

b_vec

see details below

k

see details below

tol

a calculation tolerance variable used at several points in the algorithm.

eigen_B_mat

(optional) the precalculated result eigen(B_mat).

eigen_A_mat

(optional) the precalculated result eigen(A_mat).

verbose

show progress from calculation

Details

Solves a minimization problem of the form:

min_{x} x^T A_mat x + a_vec^T x

such that x^T B_mat x + b_vec^T x + k ≤q 0,

where either A_mat or B_mat must be positive definite, but not necessarily both.

Value

a list with elements


aaronjfisher/qp1qc documentation built on Aug. 22, 2020, 2:35 p.m.